Package: rgbIndices
Type: Package
Title: RGB Visible Indices for Image Analysis
Version: 0.1.1
Authors@R: c(person("RN", "Singh", role = "aut"), person("Bappa", "Das", role = "aut"), person("Sonam", role = "aut"), person("Anil", "Kumar", role = "aut"), person("Santosha", "Rathod", email = "santoshagriculture@gmail.com", role = c("aut", "cre")))
Description: Computes RGB-based vegetation, color, and spectral indices from digital images for applications in agriculture, crop phenotyping, and remote sensing. The methods are based on digital image processing and plant phenotyping approaches (Singh et al. (2023) <doi:10.1080/10106049.2022.2160831>).
License: MIT + file LICENSE
Encoding: UTF-8
Imports: raster, tibble
Suggests: knitr, rmarkdown
VignetteBuilder: knitr
RoxygenNote: 7.3.3
NeedsCompilation: no
Packaged: 2026-04-28 11:29:58 UTC; Admin
Author: RN Singh [aut],
  Bappa Das [aut],
  Sonam [aut],
  Anil Kumar [aut],
  Santosha Rathod [aut, cre]
Maintainer: Santosha Rathod <santoshagriculture@gmail.com>
Repository: CRAN
Date/Publication: 2026-04-29 07:40:02 UTC
Built: R 4.6.0; ; 2026-05-01 21:22:24 UTC; unix

# Generated by roxygen2: do not edit by hand

export(rgb_basic)
export(rgb_color)
export(rgb_diff)
export(rgb_example)
export(rgb_indices_to_mean)
export(rgb_indices_to_tbl)
export(rgb_normdiff)
export(rgb_ratio)
export(rgb_veg)

# rgbIndices

An R package for computing RGB-based vegetation and color indices from digital images.

## Installation

```r
devtools::install_local("rgbIndices")
```

## Example

```r
library(rgbIndices)
library(raster)

# ---------------------------
# Fast example (CRAN-safe)
# ---------------------------
r <- raster(matrix(runif(30*30), 30, 30))
g <- raster(matrix(runif(30*30), 30, 30))
b <- raster(matrix(runif(30*30), 30, 30))
img <- stack(r, g, b)

# Compute indices
idx  <- rgb_basic(img)
idx1 <- rgb_diff(img)
idx2 <- rgb_ratio(img)
idx3 <- rgb_normdiff(img)
idx4 <- rgb_veg(img)
idx5 <- rgb_color(img)

# Summary statistics
rgb_indices_to_mean(idx)

# Convert to table
tbl <- rgb_indices_to_tbl(idx)
head(tbl)

# ---------------------------
# Real image example
# ---------------------------
img_real <- stack(rgb_example())
plotRGB(img_real)
rgb_basic(img_real)
```

## Applications

* Crop phenotyping
* Disease detection
* Precision agriculture
* Image-based modeling

## Reference
Singh, R. N., Krishnan, P., Singh, V. K., & Das, B. (2023). Estimation of yellow rust severity in wheat using visible and thermal imaging coupled with machine learning models. *Geocarto International*.  
https://www.tandfonline.com/doi/full/10.1080/10106049.2022.2160831
## Authors

RN Singh
Bappa Das
Sonam
Anil Kumar
Santosha Rathod (Maintainer)

Email: [santoshagriculture@gmail.com](mailto:santoshagriculture@gmail.com)

## -----------------------------------------------------------------------------
library(rgbIndices)
library(raster)

# ---------------------------
# Example
# ---------------------------
set.seed(123)
r <- raster::raster(matrix(runif(30*30), 30, 30))
g <- raster::raster(matrix(runif(30*30), 30, 30))
b <- raster::raster(matrix(runif(30*30), 30, 30))
img <- raster::stack(r, g, b)

# Compute indices
idx  <- rgb_basic(img)
idx1 <- rgb_diff(img)
idx2 <- rgb_ratio(img)
idx3 <- rgb_normdiff(img)
idx4 <- rgb_veg(img)
idx5 <- rgb_color(img)

# Summary statistics
rgb_indices_to_mean(idx)

# Convert to table
tbl <- rgb_indices_to_tbl(idx)
head(tbl)

## ----eval=FALSE---------------------------------------------------------------
# img_real <- raster::stack(rgb_example())
# raster::plotRGB(img_real)
# rgb_basic(img_real)

#' RGB difference indices
#'
#' Computes difference-based RGB indices from a three-band RGB image.
#'
#' @param image A RasterBrick or RasterStack object with three bands (R, G, B).
#'
#' @return
#' A RasterStack object where each layer represents a difference between RGB bands:
#' GRD (G - R), BGD (B - G), RGD (R - G), RBD (R - B), GBD (G - B), and BRD (B - R).
#'
#' @examples
#' set.seed(123)
#' r <- raster::raster(matrix(runif(50*50), 50, 50))
#' g <- raster::raster(matrix(runif(50*50), 50, 50))
#' b <- raster::raster(matrix(runif(50*50), 50, 50))
#' img <- raster::stack(r, g, b)
#' rgb_diff(img)
#'
#' @export
rgb_diff <- function(image){
  suppressWarnings({
    img <- raster::brick(image)
    R <- img[[1]]; G <- img[[2]]; B <- img[[3]]
    out <- raster::stack(G-R, B-G, R-G, R-B, G-B, B-R)
    names(out) <- c("GRD","BGD","RGD","RBD","GBD","BRD")
    out[!is.finite(out)] <- NA
    out
  })
}

#' Basic RGB indices
#'
#' Computes basic RGB indices including normalized red (r), green (g),
#' blue (b), and intensity (INT) from an RGB image.
#'
#' @param image A RasterBrick or RasterStack object with three bands (R, G, B).
#'
#' @return
#' A RasterStack object with seven layers:
#' \itemize{
#'   \item R, G, B: Original red, green, and blue bands
#'   \item r, g, b: Normalized RGB indices
#'   \item INT: Intensity component (mean of R, G, B)
#' }
#'
#' @examples
#' set.seed(123)
#' r <- raster::raster(matrix(runif(50*50), 50, 50))
#' g <- raster::raster(matrix(runif(50*50), 50, 50))
#' b <- raster::raster(matrix(runif(50*50), 50, 50))
#' img <- raster::stack(r, g, b)
#' rgb_basic(img)
#'
#' @export
rgb_basic <- function(image){
  suppressWarnings({
    img <- raster::brick(image)
    R <- img[[1]]; G <- img[[2]]; B <- img[[3]]
    r <- R/(R+G+B); g <- G/(R+G+B); b <- B/(R+G+B)
    INT <- (R+G+B)/3
    out <- raster::stack(R,G,B,r,g,b,INT)
    names(out) <- c("R","G","B","r","g","b","INT")
    out[!is.finite(out)] <- NA
    out
  })
}

#' Mean RGB indices
#'
#' Computes the mean values of RGB-based indices from a RasterBrick or RasterStack object.
#'
#' @param x A RasterBrick or RasterStack object containing RGB indices.
#'
#' @return
#' A tibble (data frame) with a single row where each column represents
#' the mean value of an RGB index computed across all pixels.
#'
#' @details
#' The function calculates the mean of each layer in the input raster object
#' using \code{raster::cellStats}. The output provides a summary of the indices
#' for the entire image.
#'
#' @examples
#' r <- raster::raster(matrix(runif(50*50), 50, 50))
#' g <- raster::raster(matrix(runif(50*50), 50, 50))
#' b <- raster::raster(matrix(runif(50*50), 50, 50))
#' img <- raster::stack(r, g, b)
#' x <- rgb_basic(img)
#'
#' rgb_indices_to_mean(x)
#'
#' @export
rgb_indices_to_mean <- function(x){
  
  vals <- raster::cellStats(x, stat = "mean", na.rm = TRUE)
  
  tibble::as_tibble(as.data.frame(t(vals)))
  
}

#' RGB ratio indices
#'
#' Computes ratio-based indices from a three-band RGB image.
#'
#' @param image A RasterBrick or RasterStack object with three bands (R, G, B).
#'
#' @return
#' A RasterStack object where each layer represents a ratio between RGB bands:
#' GRRI (G/R), GBRI (G/B), RBRI (R/B), RGRI (R/G), BGRI (B/G), and BRRI (B/R).
#'
#' @examples
#' set.seed(123)
#' r <- raster::raster(matrix(runif(50*50), 50, 50))
#' g <- raster::raster(matrix(runif(50*50), 50, 50))
#' b <- raster::raster(matrix(runif(50*50), 50, 50))
#' img <- raster::stack(r, g, b)
#' rgb_ratio(img)
#'
#' @export
rgb_ratio <- function(image){
  suppressWarnings({
    img <- raster::brick(image)
    R <- img[[1]]; G <- img[[2]]; B <- img[[3]]
    out <- raster::stack(G/R,G/B,R/B,R/G,B/G,B/R)
    names(out) <- c("GRRI","GBRI","RBRI","RGRI","BGRI","BRRI")
    out[!is.finite(out)] <- NA
    out
  })
}

#' RGB vegetation indices
#'
#' Computes vegetation-related indices from a three-band RGB image.
#'
#' @param image A RasterBrick or RasterStack object with three bands (R, G, B).
#'
#' @return
#' A RasterStack object containing multiple vegetation indices derived from RGB bands.
#' Each layer corresponds to a specific vegetation index, including:
#' WI, GRVI, IKAW, NDTI, GBI, GLI, VARI, NDI, ExG, ExR, ExGR, MxEG, ExB, and RGBVI.
#'
#' @examples
#' set.seed(123)
#' r <- raster::raster(matrix(runif(50*50), 50, 50))
#' g <- raster::raster(matrix(runif(50*50), 50, 50))
#' b <- raster::raster(matrix(runif(50*50), 50, 50))
#' img <- raster::stack(r, g, b)
#' rgb_veg(img)
#'
#' @export
rgb_veg <- function(image){
  suppressWarnings({
    img <- raster::brick(image)
    R <- img[[1]]; G <- img[[2]]; B <- img[[3]]
    r <- R/(R+G+B); g <- G/(R+G+B); b <- B/(R+G+B)
    
    out <- raster::stack((G-B)/(R-G),(G-R)/(G+R),(R-B)/(R+B),(R-G)/(R+G),(G-B)/(G+B),
                         (2*G-R-B)/(2*G+R+B),(G-R)/(G+R-B),(g-r)/(g+r),
                         2*g-r-b,1.4*r-g,3*g-2.4*r-b,1.262*G-0.884*R-0.311*B,1.4*b-g,
                         (G^2-(R*B))/(G^2+(R*B)))
    
    names(out) <- c("WI","GRVI","IKAW","NDTI","GBI","GLI","VARI","NDI",
                    "ExG","ExR","ExGR","MxEG","ExB","RGBVI")
    
    out[!is.finite(out)] <- NA
    out
  })
}

#' Load example RGB image
#'
#' Provides the file path to an example RGB image included in the package.
#' Optionally allows saving the image to a user-specified location.
#'
#' @param save_path Optional file path to save the example image.
#'
#' @return
#' A character string representing the file path to the example RGB image.
#'
#' @examples
#' # Get example image path
#' img_path <- rgb_example()
#' img_path
#'
#' # Save image to temporary location
#' rgb_example(tempfile(fileext = ".jpg"))
#'
#' @export
rgb_example <- function(save_path = NULL){
  
  path <- system.file(
    "extdata",
    "example.jpg",
    package = "rgbIndices",
    mustWork = TRUE
  )
  
  if (!is.null(save_path)) {
    file.copy(path, save_path, overwrite = TRUE)
  }
  
  return(path)
}

#' RGB color indices
#'
#' Computes multiple RGB-based color indices from a three-band RGB image.
#'
#' @param image A RasterBrick or RasterStack object with three bands (R, G, B).
#'
#' @return
#' A RasterStack object where each layer represents a specific RGB-based color index,
#' including Grey, BI, HI, RI, SI, CI, CIVE, VEG, IPCA, GLAI, SAT, OHI, TCVI, COM1, and COM2.
#'
#' @examples
#' set.seed(123)
#' r <- raster::raster(matrix(runif(50*50), 50, 50))
#' g <- raster::raster(matrix(runif(50*50), 50, 50))
#' b <- raster::raster(matrix(runif(50*50), 50, 50))
#' img <- raster::stack(r, g, b)
#' rgb_color(img)
#'
#' @export
rgb_color <- function(image){
  suppressWarnings({
    img <- raster::brick(image)
    R <- img[[1]]; G <- img[[2]]; B <- img[[3]]
    r <- R/(R+G+B); g <- G/(R+G+B); b <- B/(R+G+B)
    
    Grey <- 0.2898*r + 0.5870*g + 0.1140*b
    BI <- sqrt((R^2+G^2+B^2)/3)
    HI <- (2*R-G-B)/(G-B)
    RI <- R^2/(B*G^3)
    SI <- 2*(R-G-B)/(G-B)
    CI <- (R-B)/R
    CIVE <- 0.441*R - 0.811*G + 0.385*B + 18.78745
    VEG <- G/(R^0.667 * B^0.333)
    IPCA <- 0.994*(R-B)+0.961*(G-B)+0.914*(G-R)
    GLAI <- 25*(G-R)/(G+R-B)+1.25
    SAT <- (abs(R-G)+abs(R-B)+abs(G-B))/(3*(R+G+B)+1e-10)
    OHI <- atan(2*(R-G-B)/(30.5*(G-B)))
    TCVI <- 1.4*(2*R-2*B)/(2*R-G-2*B+255*0.4)
    ExG <- 2*g-r-b
    ExGR <- 3*g-2.4*r-b
    COM1 <- ExG + CIVE + ExGR + VEG
    COM2 <- 0.36*ExG + 0.47*CIVE + 0.17*VEG
    
    out <- raster::stack(Grey,BI,HI,RI,SI,CI,CIVE,VEG,IPCA,GLAI,SAT,OHI,TCVI,COM1,COM2)
    names(out) <- c("Grey","BI","HI","RI","SI","CI","CIVE","VEG","IPCA","GLAI","SAT","OHI","TCVI","COM1","COM2")
    out[!is.finite(out)] <- NA
    out
  })
}

#' Convert RGB indices to tibble
#'
#' Converts a RasterBrick or RasterStack object of RGB indices into a tibble.
#'
#' @param x A RasterBrick or RasterStack object containing RGB indices.
#'
#' @return
#' A tibble where each column corresponds to an RGB index
#' and each row represents a pixel from the input raster.
#'
#' @details
#' The function converts raster layers into a tabular format using
#' \code{raster::as.data.frame}, preserving layer names as column names.
#'
#' @examples
#' r <- raster::raster(matrix(runif(50*50), 50, 50))
#' g <- raster::raster(matrix(runif(50*50), 50, 50))
#' b <- raster::raster(matrix(runif(50*50), 50, 50))
#' img <- raster::stack(r, g, b)
#' x <- rgb_basic(img)
#'
#' rgb_indices_to_tbl(x)
#'
#' @export
rgb_indices_to_tbl <- function(x){
  
  df <- raster::as.data.frame(x)
  
  colnames(df) <- names(x)
  
  tibble::as_tibble(df)
  
}

#' RGB normalized difference indices
#'
#' Computes normalized difference indices from a three-band RGB image.
#'
#' @param image A RasterBrick or RasterStack object with three bands (R, G, B).
#'
#' @return
#' A RasterStack object where each layer represents a normalized difference
#' between RGB bands: NRGDI ((R - G)/(R + G + B)), NRBDI ((R - B)/(R + G + B)),
#' NGBDI ((G - B)/(R + G + B)), NGRDI ((G - R)/(R + G + B)),
#' NBGDI ((B - G)/(R + G + B)), and NBRDI ((B - R)/(R + G + B)).
#'
#' @examples
#' set.seed(123)
#' r <- raster::raster(matrix(runif(50*50), 50, 50))
#' g <- raster::raster(matrix(runif(50*50), 50, 50))
#' b <- raster::raster(matrix(runif(50*50), 50, 50))
#' img <- raster::stack(r, g, b)
#' rgb_normdiff(img)
#'
#' @export
rgb_normdiff <- function(image){
  suppressWarnings({
    img <- raster::brick(image)
    R <- img[[1]]; G <- img[[2]]; B <- img[[3]]
    out <- raster::stack((R-G)/(R+G+B),(R-B)/(R+G+B),(G-B)/(R+G+B),
                         (G-R)/(R+G+B),(B-G)/(R+G+B),(B-R)/(R+G+B))
    names(out) <- c("NRGDI","NRBDI","NGBDI","NGRDI","NBGDI","NBRDI")
    out[!is.finite(out)] <- NA
    out
  })
}

---
title: "RGB Visible Indices for Image Analysis"
author: |
  RN Singh  
  Bappa Das  
  Sonam  
  Anil Kumar  
  Santosha Rathod*  
date: "`r Sys.Date()`"
output: html_document
vignette: >
  %\VignetteIndexEntry{RGB Visible Indices for Image Analysis}
  %\VignetteEngine{knitr::rmarkdown}
---

*Corresponding author: santoshagriculture@gmail.com*

# 1. Introduction

The `rgbIndices` package provides a comprehensive set of RGB-based indices derived from digital images. These indices are widely used in agriculture, crop phenotyping, vegetation monitoring, and image-based modeling.

The package includes multiple groups of indices such as basic, difference, ratio, normalized difference, vegetation, and color indices.

---

# 2. RGB Components

An RGB image consists of three channels:

- **R**: Red (0–255)  
- **G**: Green (0–255)  
- **B**: Blue (0–255)  

---

# 3. Basic Indices

| Index | Formula |
|------|--------|
| Normalized Red (r) | R / (R + G + B) |
| Normalized Green (g) | G / (R + G + B) |
| Normalized Blue (b) | B / (R + G + B) |
| Intensity (INT) | (R + G + B) / 3 |

---

# 4. Difference Indices

| Index | Full Form | Formula |
|------|----------|--------|
| GRD | Green Red Difference | G − R |
| BGD | Blue Green Difference | B − G |
| RGD | Red Green Difference | R − G |
| RBD | Red Blue Difference | R − B |
| GBD | Green Blue Difference | G − B |
| BRD | Blue Red Difference | B − R |

---

# 5. Ratio Indices

| Index | Full Form | Formula |
|------|----------|--------|
| GRRI | Green Red Ratio Index | G / R |
| GBRI | Green Blue Ratio Index | G / B |
| RBRI | Red Blue Ratio Index | R / B |
| RGRI | Red Green Ratio Index | R / G |
| BGRI | Blue Green Ratio Index | B / G |
| BRRI | Blue Red Ratio Index | B / R |

---

# 6. Normalized Difference Indices

| Index | Full Form | Formula |
|------|----------|--------|
| NGRDI | Normalized Green Red Difference Index | (G − R) / (R + G + B) |
| NRGDI | Normalized Red Green Difference Index | (R − G) / (R + G + B) |
| NBRDI | Normalized Blue Red Difference Index | (B − R) / (R + G + B) |
| NRBDI | Normalized Red Blue Difference Index | (R − B) / (R + G + B) |
| NGBDI | Normalized Green Blue Difference Index | (G − B) / (R + G + B) |
| NBGDI | Normalized Blue Green Difference Index | (B − G) / (R + G + B) |

---

**Note:** Some normalized difference indices are sign-inverted counterparts of each other (e.g., NGRDI vs NRGDI).

# 7. Vegetation Indices

| Index | Full Form | Formula |
|------|----------|--------|
| WI | Woebbecke Index | (G − B) / (R − G) |
| GRVI | Green Red Vegetation Index | (G − R) / (G + R) |
| IKAW | Kawashima Index | (R − B) / (R + B) |
| NDTI | Normalized Difference Turbidity Index | (R − G) / (R + G) |
| GBI | Green Blue Index | (G − B) / (G + B) |
| GLI | Green Leaf Index | (2G − R − B) / (2G + R + B) |
| VARI | Visible Atmospherically Resistant Index | (G − R) / (G + R − B) |
| NDI | Normalized Difference Index | (g − r) / (g + r) |
| ExG | Excess Green Index | 2g − r − b |
| ExR | Excess Red Index | 1.4r − g |
| ExGR | Excess Green minus Red | 3g − 2.4r − b |
| MxEG | Modified Excess Green | 1.262G − 0.884R − 0.311B |
| ExB | Excess Blue | 1.4b − g |
| RGBVI | RGB Vegetation Index | (G² − RB) / (G² + RB) |

---

# 8. Color Indices

| Index | Full Form | Formula |
|------|----------|--------|
| Grey | Gray Intensity | 0.2898r + 0.5870g + 0.1140b |
| BI | Brightness Index | √((R² + G² + B²)/3) |
| HI | Hue Index | (2R − G − B) / (G − B) |
| RI | Redness Index | R² / (B × G³) |
| SI | Saturation Index | 2(R − G − B) / (G − B) |
| CI | Coloration Index | (R − B) / R |
| CIVE | Color Index of Vegetation | 0.441R − 0.811G + 0.385B + 18.78745 |
| VEG | Vegetative Index | G / (R^0.667 × B^0.333) |
| SAT | Overall Saturation Index | (|R−G| + |R−B| + |G−B|) / (3(R+G+B)) |
| OHI | Overall Hue Index | atan(2(R − G − B)/(30.5(G − B))) |
| TCVI | True Color Vegetation Index | 1.4(2R − 2B)/(2R − G − 2B + 255×0.4) |

---

# 9. Example Workflow
```{r}
library(rgbIndices)
library(raster)

# ---------------------------
# Example
# ---------------------------
set.seed(123)
r <- raster::raster(matrix(runif(30*30), 30, 30))
g <- raster::raster(matrix(runif(30*30), 30, 30))
b <- raster::raster(matrix(runif(30*30), 30, 30))
img <- raster::stack(r, g, b)

# Compute indices
idx  <- rgb_basic(img)
idx1 <- rgb_diff(img)
idx2 <- rgb_ratio(img)
idx3 <- rgb_normdiff(img)
idx4 <- rgb_veg(img)
idx5 <- rgb_color(img)

# Summary statistics
rgb_indices_to_mean(idx)

# Convert to table
tbl <- rgb_indices_to_tbl(idx)
head(tbl)
```

# ---------------------------
# Real image example
# ---------------------------
```{r eval=FALSE}
img_real <- raster::stack(rgb_example())
raster::plotRGB(img_real)
rgb_basic(img_real)
```

----

# 10. Applications

- Crop health monitoring  
- Disease detection  
- Plant phenotyping  
- Precision agriculture  
- Weed detection and classification  

# 11. Reference

Singh, R. N., Krishnan, P., Singh, V. K., & Das, B. (2023).  
Estimation of yellow rust severity in wheat using visible and thermal imaging coupled with machine learning models.  
Geocarto International.  
https://www.tandfonline.com/doi/full/10.1080/10106049.2022.2160831

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/rgb_example.R
\name{rgb_example}
\alias{rgb_example}
\title{Load example RGB image}
\usage{
rgb_example(save_path = NULL)
}
\arguments{
\item{save_path}{Optional file path to save the example image.}
}
\value{
A character string representing the file path to the example RGB image.
}
\description{
Provides the file path to an example RGB image included in the package.
Optionally allows saving the image to a user-specified location.
}
\examples{
# Get example image path
img_path <- rgb_example()
img_path

# Save image to temporary location
rgb_example(tempfile(fileext = ".jpg"))

}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/rgb_basic.R
\name{rgb_basic}
\alias{rgb_basic}
\title{Basic RGB indices}
\usage{
rgb_basic(image)
}
\arguments{
\item{image}{A RasterBrick or RasterStack object with three bands (R, G, B).}
}
\value{
A RasterStack object with seven layers:
\itemize{
  \item R, G, B: Original red, green, and blue bands
  \item r, g, b: Normalized RGB indices
  \item INT: Intensity component (mean of R, G, B)
}
}
\description{
Computes basic RGB indices including normalized red (r), green (g),
blue (b), and intensity (INT) from an RGB image.
}
\examples{
set.seed(123)
r <- raster::raster(matrix(runif(50*50), 50, 50))
g <- raster::raster(matrix(runif(50*50), 50, 50))
b <- raster::raster(matrix(runif(50*50), 50, 50))
img <- raster::stack(r, g, b)
rgb_basic(img)

}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/rgb_normdiff.R
\name{rgb_normdiff}
\alias{rgb_normdiff}
\title{RGB normalized difference indices}
\usage{
rgb_normdiff(image)
}
\arguments{
\item{image}{A RasterBrick or RasterStack object with three bands (R, G, B).}
}
\value{
A RasterStack object where each layer represents a normalized difference
between RGB bands: NRGDI ((R - G)/(R + G + B)), NRBDI ((R - B)/(R + G + B)),
NGBDI ((G - B)/(R + G + B)), NGRDI ((G - R)/(R + G + B)),
NBGDI ((B - G)/(R + G + B)), and NBRDI ((B - R)/(R + G + B)).
}
\description{
Computes normalized difference indices from a three-band RGB image.
}
\examples{
set.seed(123)
r <- raster::raster(matrix(runif(50*50), 50, 50))
g <- raster::raster(matrix(runif(50*50), 50, 50))
b <- raster::raster(matrix(runif(50*50), 50, 50))
img <- raster::stack(r, g, b)
rgb_normdiff(img)

}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/rgb_veg.R
\name{rgb_veg}
\alias{rgb_veg}
\title{RGB vegetation indices}
\usage{
rgb_veg(image)
}
\arguments{
\item{image}{A RasterBrick or RasterStack object with three bands (R, G, B).}
}
\value{
A RasterStack object containing multiple vegetation indices derived from RGB bands.
Each layer corresponds to a specific vegetation index, including:
WI, GRVI, IKAW, NDTI, GBI, GLI, VARI, NDI, ExG, ExR, ExGR, MxEG, ExB, and RGBVI.
}
\description{
Computes vegetation-related indices from a three-band RGB image.
}
\examples{
set.seed(123)
r <- raster::raster(matrix(runif(50*50), 50, 50))
g <- raster::raster(matrix(runif(50*50), 50, 50))
b <- raster::raster(matrix(runif(50*50), 50, 50))
img <- raster::stack(r, g, b)
rgb_veg(img)

}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/rgb_ratio.R
\name{rgb_ratio}
\alias{rgb_ratio}
\title{RGB ratio indices}
\usage{
rgb_ratio(image)
}
\arguments{
\item{image}{A RasterBrick or RasterStack object with three bands (R, G, B).}
}
\value{
A RasterStack object where each layer represents a ratio between RGB bands:
GRRI (G/R), GBRI (G/B), RBRI (R/B), RGRI (R/G), BGRI (B/G), and BRRI (B/R).
}
\description{
Computes ratio-based indices from a three-band RGB image.
}
\examples{
set.seed(123)
r <- raster::raster(matrix(runif(50*50), 50, 50))
g <- raster::raster(matrix(runif(50*50), 50, 50))
b <- raster::raster(matrix(runif(50*50), 50, 50))
img <- raster::stack(r, g, b)
rgb_ratio(img)

}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/rgb_diff.R
\name{rgb_diff}
\alias{rgb_diff}
\title{RGB difference indices}
\usage{
rgb_diff(image)
}
\arguments{
\item{image}{A RasterBrick or RasterStack object with three bands (R, G, B).}
}
\value{
A RasterStack object where each layer represents a difference between RGB bands:
GRD (G - R), BGD (B - G), RGD (R - G), RBD (R - B), GBD (G - B), and BRD (B - R).
}
\description{
Computes difference-based RGB indices from a three-band RGB image.
}
\examples{
set.seed(123)
r <- raster::raster(matrix(runif(50*50), 50, 50))
g <- raster::raster(matrix(runif(50*50), 50, 50))
b <- raster::raster(matrix(runif(50*50), 50, 50))
img <- raster::stack(r, g, b)
rgb_diff(img)

}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/rgb_color.R
\name{rgb_color}
\alias{rgb_color}
\title{RGB color indices}
\usage{
rgb_color(image)
}
\arguments{
\item{image}{A RasterBrick or RasterStack object with three bands (R, G, B).}
}
\value{
A RasterStack object where each layer represents a specific RGB-based color index,
including Grey, BI, HI, RI, SI, CI, CIVE, VEG, IPCA, GLAI, SAT, OHI, TCVI, COM1, and COM2.
}
\description{
Computes multiple RGB-based color indices from a three-band RGB image.
}
\examples{
set.seed(123)
r <- raster::raster(matrix(runif(50*50), 50, 50))
g <- raster::raster(matrix(runif(50*50), 50, 50))
b <- raster::raster(matrix(runif(50*50), 50, 50))
img <- raster::stack(r, g, b)
rgb_color(img)

}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/rgb_indices_to_mean.R
\name{rgb_indices_to_mean}
\alias{rgb_indices_to_mean}
\title{Mean RGB indices}
\usage{
rgb_indices_to_mean(x)
}
\arguments{
\item{x}{A RasterBrick or RasterStack object containing RGB indices.}
}
\value{
A tibble (data frame) with a single row where each column represents
the mean value of an RGB index computed across all pixels.
}
\description{
Computes the mean values of RGB-based indices from a RasterBrick or RasterStack object.
}
\details{
The function calculates the mean of each layer in the input raster object
using \code{raster::cellStats}. The output provides a summary of the indices
for the entire image.
}
\examples{
r <- raster::raster(matrix(runif(50*50), 50, 50))
g <- raster::raster(matrix(runif(50*50), 50, 50))
b <- raster::raster(matrix(runif(50*50), 50, 50))
img <- raster::stack(r, g, b)
x <- rgb_basic(img)

rgb_indices_to_mean(x)

}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/rgb_indices_to_tbl.R
\name{rgb_indices_to_tbl}
\alias{rgb_indices_to_tbl}
\title{Convert RGB indices to tibble}
\usage{
rgb_indices_to_tbl(x)
}
\arguments{
\item{x}{A RasterBrick or RasterStack object containing RGB indices.}
}
\value{
A tibble where each column corresponds to an RGB index
and each row represents a pixel from the input raster.
}
\description{
Converts a RasterBrick or RasterStack object of RGB indices into a tibble.
}
\details{
The function converts raster layers into a tabular format using
\code{raster::as.data.frame}, preserving layer names as column names.
}
\examples{
r <- raster::raster(matrix(runif(50*50), 50, 50))
g <- raster::raster(matrix(runif(50*50), 50, 50))
b <- raster::raster(matrix(runif(50*50), 50, 50))
img <- raster::stack(r, g, b)
x <- rgb_basic(img)

rgb_indices_to_tbl(x)

}
